@@ -8,19 +8,18 @@ from logging import Logger
 from pathlib import Path
 from typing import Dict, Iterable, Optional, Sequence
 
-import black
-from black import Mode, TargetVersion
 from docutils.core import publish_doctree
 from docutils.frontend import OptionParser, Values
 from docutils.io import FileInput, FileOutput
 from docutils.nodes import document
 from docutils.parsers.rst import Parser
+from docutils.utils import new_document
 from docutils.writers import Writer
 from sphinx.application import Sphinx
 from sphinx.environment import BuildEnvironment
 from sphinxcontrib.builders.rst import RstBuilder
 
-from bpystubgen.nodes import Class, Module
+from bpystubgen.nodes import Class, Import, Module
 from bpystubgen.writer import StubWriter
 
 
@@ -30,7 +29,6 @@ class TaskContext:
     writer: Writer
     settings: Values
     logger: Logger
-    format: bool
     total: int
     successful: int = 0
     failed: int = 0
@@ -78,7 +76,7 @@ class Task:
 
     @property
     def is_module(self) -> bool:
-        return self.source and not self.is_class
+        return not self.is_class
 
     @property
     def is_class(self) -> bool:
@@ -118,14 +116,6 @@ class Task:
         context.logger.info("Processing %s (%d of %d)", self.full_name, context.done + 1, context.total)
 
         try:
-            target: Optional[Path] = None
-
-            if self.is_module and (self.source or any(self.children)):
-                parent_dir = Path(context.dest_dir, "/".join(self.full_name.split("."))).resolve()
-                target = parent_dir / "__init__.pyi"
-
-                context.logger.debug("Generating module: %s", target)
-
             if self.source:
                 source_path = str(self.source)
 
@@ -141,46 +131,53 @@ class Task:
                     source_class=FileInput,
                     source_path=source_path,
                     settings=context.settings)
+            elif self.is_module:
+                components = (Parser,)
+                settings = OptionParser(components=components).get_default_values()
 
-                if self.is_module and target:
-                    try:
-                        module = next(iter(self.doctree.traverse(Module)))
+                self.doctree = new_document("", settings=settings)
+                self.doctree += Module(name=self.name)
 
-                        for child in filter(lambda c: c.is_class and c.doctree, self.children.values()):
-                            for node in child.doctree.traverse(Class):
-                                node.parent.remove(node)
-                                module += node
+            if not self.is_module or not (self.source or any(self.doctree.children)):
+                return
 
-                        module.import_types()
-                        module.sort_members()
+            parent_dir = Path(context.dest_dir, "/".join(self.full_name.split("."))).resolve()
+            target = parent_dir / "__init__.pyi"
 
-                        target.parent.mkdir(parents=True, exist_ok=True)
+            context.logger.debug("Generating module: %s", target)
 
-                        output_path = str(target)
-                        fout = FileOutput(destination_path=output_path)
+            try:
+                module = next(iter(self.doctree.traverse(Module)))
 
-                        marker = target.parent / "py.typed"
+                for child in filter(lambda c: c.is_class, self.children.values()):
+                    for node in child.doctree.traverse(Class):
+                        node.parent.remove(node)
+                        module += node
 
-                        with open(marker, "w"):
-                            pass
+                module.import_types()
+                module.sort_members()
 
-                        context.logger.debug("Generating stub file: %s", output_path)
+                index = 1 if module.docstring else 0
 
-                        context.writer.write(self.doctree, fout)
-                        context.writer.assemble_parts()
+                for child in filter(lambda c: c.is_module, self.children.values()):
+                    for node in child.doctree.traverse(Module):
+                        module.insert(index, Import(module=".", types=module.localise_name(node.name)))
 
-                        if context.format:
-                            mode = Mode(
-                                target_versions={TargetVersion.PY39},
-                                line_length=100,
-                                string_normalization=True,
-                                is_pyi=True,
-                                experimental_string_processing=True
-                            )
+                target.parent.mkdir(parents=True, exist_ok=True)
 
-                            black.format_file_in_place(target, True, mode, black.WriteBack.YES)
-                    except StopIteration:
-                        context.logger.warning("Parsed doctree does not contain any module: %s", self.full_name)
+                output_path = str(target)
+
+                context.logger.debug("Generating stub file: %s", output_path)
+
+                marker = target.parent / "py.typed"
+
+                with open(marker, "w"):
+                    pass
+
+                context.writer.write(self.doctree, FileOutput(destination_path=output_path))
+                context.writer.assemble_parts()
+            except StopIteration:
+                context.logger.warning("Parsed doctree does not contain any module: %s", self.full_name)
 
             context.successful += 1
         except BaseException as e:
@@ -189,7 +186,7 @@ class Task:
             context.logger.error("Failed to process task %s", self.name, exc_info=e)
 
 
-def generate(src_dir: Path, dest_dir: Path, format_source: bool = False, log_level: int = logging.INFO) -> None:
+def generate(src_dir: Path, dest_dir: Path, log_level: int = logging.INFO) -> None:
     logging.basicConfig(level=log_level, format="[%(levelname)s] %(name)s - %(message)s")
 
     logger = logging.getLogger("bpystubgen")
@@ -223,7 +220,7 @@ def generate(src_dir: Path, dest_dir: Path, format_source: bool = False, log_lev
 
     writer = StubWriter(builder)
 
-    context = TaskContext(dest_dir, writer, settings, logger, format_source, root.total)
+    context = TaskContext(dest_dir, writer, settings, logger, root.total)
 
     root.run(context)
 
